AppPackage class

A class that represents an application package.

This class can be used to define and manage the properties and behaviors associated with an application package.

Constructors

AppPackage({required int uid, required String name, required String packageName, Uint8List? icon, String? sourceDir, String? dataDir, String? publicSourceDir, String? processName, String? installer, int? versionCode, String? versionName, DateTime? firstInstallTime, DateTime? lastUpdateTime, List<Signature> signingCertificates = const [], List<String> permissions = const []})
AppPackage.fromMap(Map<String, dynamic> map)
factory

Properties

dataDir ↔ String?
The data directory of the application.
getter/setter pair
firstInstallTime ↔ DateTime?
The date and time when the application was first installed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ Uint8List?
The icon of the application as a byte array.
getter/setter pair
installer ↔ String?
The installer of the application.
getter/setter pair
lastUpdateTime ↔ DateTime?
The date and time when the application was last updated.
getter/setter pair
name ↔ String
The name of the application.
getter/setter pair
packageName ↔ String
The package name of the application.
getter/setter pair
permissions ↔ List<String>
The list of permissions required by the application.
getter/setter pair
processName ↔ String?
The process name associated with the application.
getter/setter pair
publicSourceDir ↔ String?
The public source directory of the application.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signingCertificates ↔ List<Signature>
The list of signing certificates associated with the application.
getter/setter pair
sourceDir ↔ String?
The source directory of the application.
getter/setter pair
uid ↔ int
The unique identifier for the application package.
getter/setter pair
versionCode ↔ int?
The version code of the application.
getter/setter pair
versionName ↔ String?
The version name of the application.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited