Signature class

A class representing a digital signature.

This class can be used to handle and manage digital signatures for secure communication or data validation purposes.

Constructors

Signature({required String hash, required String signature, String? subjectDN, String? issuerDN, String? serialNumber, DateTime? notBefore, DateTime? notAfter, String? publicKeyAlgorithm, String? publicKeyFormat, Uint8List? publicKeyEncoded, String? publicKey, String? publicKeyHash})
Signature.fromMap(Map<String, dynamic> map)
factory

Properties

hash ↔ String
The hash of the signature.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
issuerDN ↔ String?
The issuer distinguished name of the certificate.
getter/setter pair
notAfter ↔ DateTime?
The end date of the certificate's validity period.
getter/setter pair
notBefore ↔ DateTime?
The start date of the certificate's validity period.
getter/setter pair
publicKey ↔ String?
The public key value.
getter/setter pair
publicKeyAlgorithm ↔ String?
The algorithm used for the public key.
getter/setter pair
publicKeyEncoded ↔ Uint8List?
The encoded public key as a byte array.
getter/setter pair
publicKeyFormat ↔ String?
The format of the public key.
getter/setter pair
publicKeyHash ↔ String?
The hash of the public key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber ↔ String?
The serial number of the certificate.
getter/setter pair
signature ↔ String
The signature value.
getter/setter pair
subjectDN ↔ String?
The subject distinguished name of the certificate.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited